tt_type_comp(1)

tt_type_comp - The ToolTalk otype and ptype compiler

Showing IRIX 6.5.30 (default release). Unchanged since IRIX 6.5.

NAME
     tt_type_comp - The ToolTalk otype and ptype compiler

SYNOPSIS
     tt_type_comp [-d {user|system|network}] [-o ofile ] [-s] -{p|O|P|h|v|{r
     type1..typeN }|[m|x] file }

DESCRIPTION
     tt_type_comp is the ToolTalk compiler for the otypes and ptypes provided
     in the specified typefile.  The typefile is first run through cpp and
     then parsed and checked for correctness. The compiler produces files for
     the types database XDR format.  The default function of tt_type_comp when
     given a file containing definitions for ToolTalk otypes or ptypes is to
     merge the types in to the existing user database of types.

     Differences from SunSoft ToolTalk:

     The Classing Engine is NOT supported on SGI.  The types database XDR
     format is the only usable format.  The following options are used to
     support the Classing Engine in the SunSoft implementation: -c, -x, -X.
     These are  NOT supported on SGI.

OPTIONS
     -d   Specify the database to work on which should be one of user
          (default), system, or network.

          For the types database XDR-base format these are defined as:

               user: ~/.tt/types.xdr

               system: /etc/tt/types.xdr

               network:$OPENWINHOME/tt/types.xdr

          These three databases form a hierarchy of database where the
          definition of a type in the user database overrides the definition
          in the system database and so on.

     -o outputfile
          Output to the given file name.

     -s   Silent mode. Don't print out anything.

     -p   Print the ToolTalk types as seen by ttsession.  Note that the -d
          option is ignored in this case.  Types are printed out in source
          format suitable for recompilation with tt_type_comp.

     -O   Print out list of known otypes.

     -P   Print out list of known ptypes.
     -h   Print help on invoking tt_type_comp and exit.  All other options are
          ignored (except -v if -v precedes -h).

     -v   Print out the version number and exit.  All other options are
          ignored (except -h if -h precedes -v).

     -r type1 ... typeN
          Remove the given ptypes or otypes from the database.

     -m   Merge types into specified database. This is the default option if
          neither -m or -x are specified and an input file is specified.

     -x   Produce an xdr format type file <file>.xdr.

ENVIRONMENT
     tt_type_comp will use the CEPATH variable for its definition of where the
     databases are located. This variable should be a list of three components
     separated by colons (:). Each component should be the name of the file to
     use:

               <user_db>:<system_db>:<network_db>


SEE ALSO
     ttsession(1)